@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+from __future__ import unicode_literals
 from .killmail import CRESTMail, ZKillmail
 
 CSRF_ENABLE = True
